@@ -23,7 +23,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """
 
 
-__version__ = "0.3.31"
+__version__ = "0.3.32"
 __author__ = "nagev"
 __license__ = "GPLv3"
 
@@ -62,12 +62,11 @@ def _extract_function_from_js(name, js):
 
     """
 
-    # handle dollar symbol in function name
-    name = name.replace("$", "\\$")
-    m = re.search(r'function %s\(((?:\w+,?)+)\)\{([^}]+)\}' % name, js)
-    logging.debug(m.group(0))
-    return {'name': name, 'parameters': m.group(1).split(","),
-            'body': m.group(2)}
+    fpattern = r'function\s%s\(((?:\w+,?)+)\)\{([^}]+)\}'
+    m = re.search(fpattern % re.escape(name), js)
+    args, body = m.groups()
+    logging.debug("extracted function %s(%s){%s};", name, args, body)
+    return {'name': name, 'parameters': args.split(","), 'body': body}
 
 
 def _getval(val, argsdict):
@@ -540,6 +539,7 @@ class Pafy(object):
             self.m4astreams, self.oggstreams = m4astreams, oggstreams
 
         self.allstreams = self.streams + self.videostreams + self.audiostreams
+        self.expires = int(time.time()) + (60 * 60 * 4.8)
 
     def getbest(self, preftype="any", ftypestrict=True):
         """
